==> registry-model-5.4.1-20240801.135154-1-sources.jar: de/uniba/minf/registry/model/serialization/base/BaseDefinitionSerializationConstants.java <==
package de.uniba.minf.registry.model.serialization.base;

public class BaseDefinitionSerializationConstants {
	private BaseDefinitionSerializationConstants() {}
	
	public static final String PROPERTIES_FIELD = "properties";
	public static final String PREVIEW_PROPERTIES_FIELD = "preview_properties";
	public static final String PROPERTY_BLOCKS_FIELD = "blocks";
	public static final String FIELD_FIELD = "field";
	public static final String VOCABULARY_FIELD = "vocabulary";
	public static final String VOCABULARY_ENTITY_FIELD = "entity";
	
	
	public static final String PROPERTY_MANDATORY_FIELD = "mandatory";
	public static final String PROPERTY_IDENTIFIER_FIELD = "identifier";
	public static final String PROPERTY_MULTIPLE_FIELD = "multiple";
	public static final String PROPERTY_VALID_FIELD = "valid";
	public static final String PROPERTY_MULTILANG_FIELD = "multilang";
	public static final String PROPERTY_COMPOSITION_METHOD = "compositionMethod";
	public static final String PROPERTY_COMPOSITION_FLAG = "compositionFlag";
	
	public static final String PROPERTY_NAME_FIELD = "name";
	public static final String PROPERTY_CODE_FIELD = "code";
	public static final String SYSTEM_ENTITY_FIELD = "system";
	
	public static final String PROPERTY_VOCABULARY_STRICT_FIELD = "strict";
	public static final String PROPERTY_VOCABULARY_DEFAULT_FIELD = "default";
	public static final String PROPERTY_VOCABULARY_QUERY_FIELD = "query";
	public static final String PROPERTY_VOCABULARY_AUTOQUERY_FIELD = "autoquery";
	public static final String PROPERTY_VOCABULARY_AUTOFILL_FIELD = "autofill";
	public static final String PROPERTY_VOCABULARY_INVERTIBLE_FIELD = "invertible";
	
	public static final String ENTITY_PRESENTATION_PROPERTIES_FIELD = "presentation";
	public static final String ENTITY_NAME_FIELD = "entity";
	public static final String ENTITY_PRIMARY_FIELD = "primary";
	public static final String ENTITY_COMPOSITING_FIELD = "compositing";
	public static final String ENTITY_LOCAL_CREATION_FIELD = "localCreation";
	
	public static final String ENTITY_RELATION_NAME = "relation";
	public static final String ENTITY_RELATION_SOURCE = "source";
	public static final String ENTITY_RELATION_TARGET = "target";
	public static final String ENTITY_RELATION_RELATED_ENTITY = "_related_entity";
	
}

==> registry-model-5.4-20240607.115459-9-sources.jar: de/uniba/minf/registry/model/serialization/base/BaseDefinitionSerializationConstants.java <==
package de.uniba.minf.registry.model.serialization.base;

public class BaseDefinitionSerializationConstants {
	private BaseDefinitionSerializationConstants() {}
	
	public static final String PROPERTIES_FIELD = "properties";
	public static final String PREVIEW_PROPERTIES_FIELD = "preview_properties";
	public static final String PROPERTY_BLOCKS_FIELD = "blocks";
	public static final String FIELD_FIELD = "field";
	public static final String VOCABULARY_FIELD = "vocabulary";
	public static final String VOCABULARY_ENTITY_FIELD = "entity";
	public static final String VOCABULARY_ENTITY_RELATION_VOCABULARY_FIELD = "relation_vocabulary";
	public static final String VOCABULARY_ENTITY_RELATION_TYPE_FIELD = "relation_type";
	
	
	public static final String PROPERTY_MANDATORY_FIELD = "mandatory";
	public static final String PROPERTY_IDENTIFIER_FIELD = "identifier";
	public static final String PROPERTY_MULTIPLE_FIELD = "multiple";
	public static final String PROPERTY_VALID_FIELD = "valid";
	public static final String PROPERTY_MULTILANG_FIELD = "multilang";
	
	public static final String PROPERTY_NAME_FIELD = "name";
	public static final String PROPERTY_CODE_FIELD = "code";
	public static final String SYSTEM_ENTITY_FIELD = "system";
	
	public static final String PROPERTY_VOCABULARY_STRICT_FIELD = "strict";
	public static final String PROPERTY_VOCABULARY_DEFAULT_FIELD = "default";
	public static final String PROPERTY_VOCABULARY_QUERY_FIELD = "query";
	public static final String PROPERTY_VOCABULARY_AUTOQUERY_FIELD = "autoquery";
	public static final String PROPERTY_VOCABULARY_AUTOFILL_FIELD = "autofill";
	
	public static final String ENTITY_PRESENTATION_PROPERTIES_FIELD = "presentation";
	public static final String ENTITY_NAME_FIELD = "entity";
	public static final String ENTITY_PRIMARY_FIELD = "primary";
	public static final String ENTITY_COMPOSITING_FIELD = "compositing";
	public static final String ENTITY_LOCAL_CREATION_FIELD = "localCreation";
}
